nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Hcsparams

Struct Hcsparams 

#[repr(transparent)]
pub struct Hcsparams(pub u32);
Host Controller Structural Parameters

Tuple Fields

0: u32

Implementations

Source

impl Hcsparams

pub const fn n_ports(&self) -> u8

This register specifies the number of physical downstream ports implemented on this host controller.

pub const fn set_n_ports(&mut self, val: u8)

This register specifies the number of physical downstream ports implemented on this host controller.

pub const fn ppc(&self) -> bool

This field indicates whether the host controller implementation includes port power control.

pub const fn set_ppc(&mut self, val: bool)

This field indicates whether the host controller implementation includes port power control.

pub const fn p_indicator(&self) -> bool

This bit indicates whether the ports support port indicator control.

pub const fn set_p_indicator(&mut self, val: bool)

This bit indicates whether the ports support port indicator control.