#[repr(transparent)]pub struct Intptds(pub u32);Expand description
Skip map for each INT PTD
Tuple Fields
0: u32Implementations
Sourceimpl Intptds
impl Intptds
Sourcepub const fn int_skip(&self) -> u32
pub const fn int_skip(&self) -> u32
When a bit in the PTD Skip Map is set to logic 1, the corresponding PTD will be skipped, independent of the V bit setting.
Sourcepub const fn set_int_skip(&mut self, val: u32)
pub const fn set_int_skip(&mut self, val: u32)
When a bit in the PTD Skip Map is set to logic 1, the corresponding PTD will be skipped, independent of the V bit setting.