nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Portmode

Struct Portmode 

#[repr(transparent)]
pub struct Portmode(pub u32);
Controls the port if it is attached to the host block or the device block

Tuple Fields

0: u32

Implementations

Source

impl Portmode

pub const fn dev_enable(&self) -> bool

If this bit is set to one, one of the ports will behave as a USB device.

pub const fn set_dev_enable(&mut self, val: bool)

If this bit is set to one, one of the ports will behave as a USB device.

pub const fn sw_ctrl_pdcom(&self) -> bool

This bit indicates if the PHY power-down input is controlled by software or by hardware.

pub const fn set_sw_ctrl_pdcom(&mut self, val: bool)

This bit indicates if the PHY power-down input is controlled by software or by hardware.

pub const fn sw_pdcom(&self) -> bool

This bit is only used when SW_CTRL_PDCOM is set to 1b.

pub const fn set_sw_pdcom(&mut self, val: bool)

This bit is only used when SW_CTRL_PDCOM is set to 1b.