nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Portsc1

Struct Portsc1 

#[repr(transparent)]
pub struct Portsc1(pub u32);
Port Status and Control register

Tuple Fields

0: u32

Implementations

Source

impl Portsc1

pub const fn ccs(&self) -> bool

Current Connect Status: Logic 1 indicates a device is present on the port.

pub const fn set_ccs(&mut self, val: bool)

Current Connect Status: Logic 1 indicates a device is present on the port.

pub const fn csc(&self) -> bool

Connect Status Change: Logic 1 means that the value of CCS has changed.

pub const fn set_csc(&mut self, val: bool)

Connect Status Change: Logic 1 means that the value of CCS has changed.

pub const fn ped(&self) -> bool

Port Enabled/Disabled.

pub const fn set_ped(&mut self, val: bool)

Port Enabled/Disabled.

pub const fn pedc(&self) -> bool

Port Enabled/Disabled Change: Logic 1 means that the value of PED has changed.

pub const fn set_pedc(&mut self, val: bool)

Port Enabled/Disabled Change: Logic 1 means that the value of PED has changed.

pub const fn oca(&self) -> bool

Over-current active: Logic 1 means that this port has an over-current condition.

pub const fn set_oca(&mut self, val: bool)

Over-current active: Logic 1 means that this port has an over-current condition.

pub const fn occ(&self) -> bool

Over-current change: Logic 1 means that the value of OCA has changed.

pub const fn set_occ(&mut self, val: bool)

Over-current change: Logic 1 means that the value of OCA has changed.

pub const fn fpr(&self) -> bool

Force Port Resume: Logic 1 means resume (K-state) detected or driven on the port.

pub const fn set_fpr(&mut self, val: bool)

Force Port Resume: Logic 1 means resume (K-state) detected or driven on the port.

pub const fn susp(&self) -> bool

Suspend: Logic 1 means port is in the suspend state.

pub const fn set_susp(&mut self, val: bool)

Suspend: Logic 1 means port is in the suspend state.

pub const fn pr(&self) -> bool

Port Reset: Logic 1 means the port is in the reset state.

pub const fn set_pr(&mut self, val: bool)

Port Reset: Logic 1 means the port is in the reset state.

pub const fn ls(&self) -> u8

Line Status: This field reflects the current logical levels of the DP (bit 11) and DM (bit 10) signal lines.

pub const fn set_ls(&mut self, val: u8)

Line Status: This field reflects the current logical levels of the DP (bit 11) and DM (bit 10) signal lines.

pub const fn pp(&self) -> bool

Port Power: The function of this bit depends on the value of the Port Power Control (PPC) bit in the HCSPARAMS register.

pub const fn set_pp(&mut self, val: bool)

Port Power: The function of this bit depends on the value of the Port Power Control (PPC) bit in the HCSPARAMS register.

pub const fn pic(&self) -> u8

Port Indicator Control : Writing to this field has no effect if the P_INDICATOR bit in the HCSPARAMS register is logic 0.

pub const fn set_pic(&mut self, val: u8)

Port Indicator Control : Writing to this field has no effect if the P_INDICATOR bit in the HCSPARAMS register is logic 0.

pub const fn ptc(&self) -> u8

Port Test Control: A non-zero value indicates that the port is operating in the test mode as indicated by the value.

pub const fn set_ptc(&mut self, val: u8)

Port Test Control: A non-zero value indicates that the port is operating in the test mode as indicated by the value.

pub const fn pspd(&self) -> u8

Port Speed: 00b: Low-speed 01b: Full-speed 10b: High-speed 11b: Reserved.

pub const fn set_pspd(&mut self, val: u8)

Port Speed: 00b: Low-speed 01b: Full-speed 10b: High-speed 11b: Reserved.

pub const fn woo(&self) -> bool

Wake on overcurrent enable: Writing this bit to a one enables the port to be sensitive to overcurrent conditions as wake-up events.

pub const fn set_woo(&mut self, val: bool)

Wake on overcurrent enable: Writing this bit to a one enables the port to be sensitive to overcurrent conditions as wake-up events.