nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Usbcmd

Struct Usbcmd 

#[repr(transparent)]
pub struct Usbcmd(pub u32);
USB Command register

Tuple Fields

0: u32

Implementations

Source

impl Usbcmd

pub const fn rs(&self) -> bool

Run/Stop: 1b = Run.

pub const fn set_rs(&mut self, val: bool)

Run/Stop: 1b = Run.

pub const fn hcreset(&self) -> bool

Host Controller Reset: This control bit is used by the software to reset the host controller.

pub const fn set_hcreset(&mut self, val: bool)

Host Controller Reset: This control bit is used by the software to reset the host controller.

pub const fn fls(&self) -> u8

Frame List Size: This field specifies the size of the frame list.

pub const fn set_fls(&mut self, val: u8)

Frame List Size: This field specifies the size of the frame list.

pub const fn lhcr(&self) -> bool

Light Host Controller Reset: This bit allows the driver software to reset the host controller without affecting the state of the ports.

pub const fn set_lhcr(&mut self, val: bool)

Light Host Controller Reset: This bit allows the driver software to reset the host controller without affecting the state of the ports.

pub const fn atl_en(&self) -> bool

ATL List enabled.

pub const fn set_atl_en(&mut self, val: bool)

ATL List enabled.

pub const fn iso_en(&self) -> bool

ISO List enabled.

pub const fn set_iso_en(&mut self, val: bool)

ISO List enabled.

pub const fn int_en(&self) -> bool

INT List enabled.

pub const fn set_int_en(&mut self, val: bool)

INT List enabled.