#[repr(transparent)]pub struct Usbsts(pub u32);Expand description
USB Interrupt Status register
Tuple Fields
0: u32Implementations
Sourceimpl Usbsts
impl Usbsts
Sourcepub const fn pcd(&self) -> bool
pub const fn pcd(&self) -> bool
Port Change Detect: The host controller sets this bit to logic 1 when any port has a change bit transition from a 0 to a one or a Force Port Resume bit transition from a 0 to a 1 as a result of a J-K transition detected on a suspended port.
Sourcepub const fn set_pcd(&mut self, val: bool)
pub const fn set_pcd(&mut self, val: bool)
Port Change Detect: The host controller sets this bit to logic 1 when any port has a change bit transition from a 0 to a one or a Force Port Resume bit transition from a 0 to a 1 as a result of a J-K transition detected on a suspended port.
Sourcepub const fn flr(&self) -> bool
pub const fn flr(&self) -> bool
Frame List Rollover: The host controller sets this bit to logic 1 when the frame list index rolls over its maximum value to 0.
Sourcepub const fn set_flr(&mut self, val: bool)
pub const fn set_flr(&mut self, val: bool)
Frame List Rollover: The host controller sets this bit to logic 1 when the frame list index rolls over its maximum value to 0.
Sourcepub const fn atl_irq(&self) -> bool
pub const fn atl_irq(&self) -> bool
ATL IRQ: Indicates that an ATL PTD (with I-bit set) was completed.
Sourcepub const fn set_atl_irq(&mut self, val: bool)
pub const fn set_atl_irq(&mut self, val: bool)
ATL IRQ: Indicates that an ATL PTD (with I-bit set) was completed.
Sourcepub const fn iso_irq(&self) -> bool
pub const fn iso_irq(&self) -> bool
ISO IRQ: Indicates that an ISO PTD (with I-bit set) was completed.
Sourcepub const fn set_iso_irq(&mut self, val: bool)
pub const fn set_iso_irq(&mut self, val: bool)
ISO IRQ: Indicates that an ISO PTD (with I-bit set) was completed.
Sourcepub const fn int_irq(&self) -> bool
pub const fn int_irq(&self) -> bool
INT IRQ: Indicates that an INT PTD (with I-bit set) was completed.
Sourcepub const fn set_int_irq(&mut self, val: bool)
pub const fn set_int_irq(&mut self, val: bool)
INT IRQ: Indicates that an INT PTD (with I-bit set) was completed.
Sourcepub const fn sof_irq(&self) -> bool
pub const fn sof_irq(&self) -> bool
SOF interrupt: Every time when the host sends a Start of Frame token on the USB bus, this bit is set.
Sourcepub const fn set_sof_irq(&mut self, val: bool)
pub const fn set_sof_irq(&mut self, val: bool)
SOF interrupt: Every time when the host sends a Start of Frame token on the USB bus, this bit is set.